@@ -16,12 +16,14 @@ To restore the Seurat default display use options(\"restore_Seurat_show\" = TRUE
 ")	
 	
 	packageStartupMessage(msg)
+    # Attach tidyverse
+    attached <- tidyverse_attach()
 }
 
-rv = R.Version()
+# rv = R.Version()
 
-if(getRversion() >= "4.0.0" && as.numeric(rv$`svn rev`) >= 77889) {
-	unitType = get("unitType", envir = asNamespace("grid"))
-} else {
-	unitType = function(x, recurse = TRUE) attr(x, "unit")
-}
\ No newline at end of file
+# if(getRversion() >= "4.0.0" && as.numeric(rv$`svn rev`) >= 77889) {
+# 	unitType = get("unitType", envir = asNamespace("grid"))
+# } else {
+# 	unitType = function(x, recurse = TRUE) attr(x, "unit")
+# }
\ No newline at end of file
